/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 479 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 964 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1221 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1295 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1316 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1518 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1734 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 272
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 76
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  SrcList* yy27;
  bool yy28;
  struct LimitVal yy36;
  struct type_def yy58;
  Expr* yy60;
  struct Expr * yy71;
  With* yy79;
  int yy82;
  TriggerStep* yy93;
  ExprList* yy126;
  ExprSpan yy146;
  struct Token yy193;
  IdList* yy200;
  enum trim_side_mask yy221;
  struct alter_args yy402;
  struct ExprList * yy465;
  struct TrigEvent yy466;
  Select* yy497;
  struct SrcList * yy512;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             436
#define YYNRULE              317
#define YY_MAX_SHIFT         435
#define YY_MIN_SHIFTREDUCE   657
#define YY_MAX_SHIFTREDUCE   973
#define YY_MIN_REDUCE        974
#define YY_MAX_REDUCE        1290
#define YY_ERROR_ACTION      1291
#define YY_ACCEPT_ACTION     1292
#define YY_NO_ACTION         1293
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1585)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    65,   66,  292,  312,  838,  838,  848,  851,   63,   63,
 /*    10 */    64,   64,   64,   64,  771,   62,   62,   62,   62,   61,
 /*    20 */    61,   60,   60,   60,   59,  313,   64,   64,   64,   64,
 /*    30 */    57,   62,   62,   62,   62,   61,   61,   60,   60,   60,
 /*    40 */    59,  313,  963,   48,  963,   46,  675,  675,   65,   66,
 /*    50 */   292,  312,  838,  838,  848,  851,   63,   63,   64,   64,
 /*    60 */    64,   64,  252,   62,   62,   62,   62,   61,   61,   60,
 /*    70 */    60,   60,   59,  313,  195,   58,   56,  188,   65,   66,
 /*    80 */   292,  312,  838,  838,  848,  851,   63,   63,   64,   64,
 /*    90 */    64,   64,  221,   62,   62,   62,   62,   61,   61,   60,
 /*   100 */    60,   60,   59,  313,  869,  305,   52,   62,   62,   62,
 /*   110 */    62,   61,   61,   60,   60,   60,   59,  313,  705,  251,
 /*   120 */   366,   42,  313,   49,   50,  429,  374,  658,  317,  130,
 /*   130 */    51,  706,  932,   61,   61,   60,   60,   60,   59,  313,
 /*   140 */    67,  419,    4,   99,   99,  194,  808,  130,  314,  314,
 /*   150 */   273,  122,  306,  797,  874,  774,  775,  741,  315,  754,
 /*   160 */   315,  159,  883,  287,  882,  244,  400,  408,  290,  113,
 /*   170 */   247,  348,  341,  315,  913,   58,   56,  188,  803,  911,
 /*   180 */   403,  401,  913,   64,   64,   64,   64,  295,   62,   62,
 /*   190 */    62,   62,   61,   61,   60,   60,   60,   59,  313,  328,
 /*   200 */   421, 1292,  435,    1,  248,  255,  805,  926,  927,  928,
 /*   210 */   929,  930,  931,  275,  935,  936,  937,  937,  938,  939,
 /*   220 */   807,  807,  809,  810,  811,  812,  813,  427,  423,  823,
 /*   230 */   824,  825,  967,   21,   65,   66,  292,  312,  838,  838,
 /*   240 */   848,  851,   63,   63,   64,   64,   64,   64,  417,   62,
 /*   250 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   260 */    65,   66,  292,  312,  838,  838,  848,  851,   63,   63,
 /*   270 */    64,   64,   64,   64,  909,   62,   62,   62,   62,   61,
 /*   280 */    61,   60,   60,   60,   59,  313,   66,  292,  312,  838,
 /*   290 */   838,  848,  851,   63,   63,   64,   64,   64,   64,  914,
 /*   300 */    62,   62,   62,   62,   61,   61,   60,   60,   60,   59,
 /*   310 */   313,   59,  313,  691,   60,   60,   60,   59,  313,   65,
 /*   320 */    66,  292,  312,  838,  838,  848,  851,   63,   63,   64,
 /*   330 */    64,   64,   64,  691,   62,   62,   62,   62,   61,   61,
 /*   340 */    60,   60,   60,   59,  313,  769,  434,  434,  915,  768,
 /*   350 */   283,  912,   41,    7,  127,  228,  384,  963,  686,  963,
 /*   360 */   839,  839,  849,  852,   65,   66,  292,  312,  838,  838,
 /*   370 */   848,  851,   63,   63,   64,   64,   64,   64,  429,   62,
 /*   380 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   390 */   728,  357,  131,   71,  257,  256,   82,   82,  720,  720,
 /*   400 */    58,   56,  188,  679,   58,   56,  188,  221,  673,   65,
 /*   410 */    66,  292,  312,  838,  838,  848,  851,   63,   63,   64,
 /*   420 */    64,   64,   64,  743,   62,   62,   62,   62,   61,   61,
 /*   430 */    60,   60,   60,   59,  313,  770,  715,  912,  372,  370,
 /*   440 */   376,  171,  170,  121,  715,  286,  675,  675,  829,  422,
 /*   450 */    53,   20,  369,  421,   65,   66,  292,  312,  838,  838,
 /*   460 */   848,  851,   63,   63,   64,   64,   64,   64,  319,   62,
 /*   470 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   480 */   972,  206,  954,  291,  674,  954,  291,  151,  954,  257,
 /*   490 */   256,  954,  688,  802,  673,  688,   58,   56,  188,   65,
 /*   500 */    66,  292,  312,  838,  838,  848,  851,   63,   63,   64,
 /*   510 */    64,   64,   64,  678,   62,   62,   62,   62,   61,   61,
 /*   520 */    60,   60,   60,   59,  313,   65,   66,  292,  312,  838,
 /*   530 */   838,  848,  851,   63,   63,   64,   64,   64,   64,  325,
 /*   540 */    62,   62,   62,   62,   61,   61,   60,   60,   60,   59,
 /*   550 */   313,   65,   66,  292,  312,  838,  838,  848,  851,   63,
 /*   560 */    63,   64,   64,   64,   64,  876,   62,   62,   62,   62,
 /*   570 */    61,   61,   60,   60,   60,   59,  313,   65,   66,  292,
 /*   580 */   312,  838,  838,  848,  851,   63,   63,   64,   64,   64,
 /*   590 */    64,  308,   62,   62,   62,   62,   61,   61,   60,   60,
 /*   600 */    60,   59,  313,   52,  318,  916,  320,  681,  675,  675,
 /*   610 */   169,  168,  718,  718,  304,   58,   56,  188,  323,  181,
 /*   620 */    49,   50,  130,  900,  391,  122,  113,   51, 1269,   69,
 /*   630 */    44,  429, 1269,  808,  949,  163,  229,  287,  419,    4,
 /*   640 */  1180,  130,  290,  808,  951,  314,  314,  949,  674,   97,
 /*   650 */    97,  349,  819,  680,  389,  335,   47,  113,  189,  189,
 /*   660 */   748,  229,  166,  262,  408,  803,   72,  392, 1269,  123,
 /*   670 */   387,  347,  174,  186,  754,  803,  255,  292,  312,  838,
 /*   680 */   838,  848,  851,   63,   63,   64,   64,   64,   64,   39,
 /*   690 */    62,   62,   62,   62,   61,   61,   60,   60,   60,   59,
 /*   700 */   313,  189,  189,  805,  697,  402,  421,  807,  807,  809,
 /*   710 */   810,  811,  812,  387,  786,  675,  675,  807,  807,  809,
 /*   720 */   810,  811,  812,  813,  427,  423,  964,  964,  336,  967,
 /*   730 */    21,   65,   66,  292,  312,  838,  838,  848,  851,   63,
 /*   740 */    63,   64,   64,   64,   64,  426,   62,   62,   62,   62,
 /*   750 */    61,   61,   60,   60,   60,   59,  313,   65,   55,  292,
 /*   760 */   312,  838,  838,  848,  851,   63,   63,   64,   64,   64,
 /*   770 */    64,   52,   62,   62,   62,   62,   61,   61,   60,   60,
 /*   780 */    60,   59,  313,  801,  965,  757,  964,  964,   49,   50,
 /*   790 */  1007,  377,  685,  376,  216,   51,  308,  433,  698,  662,
 /*   800 */   432,  231,  284,  797,  351,  668,  419,    4,  903,  130,
 /*   810 */   130,  808,  351,  314,  314,  154,  699,  700,  701,  304,
 /*   820 */   236,  338,   52,  687,  904,  257,  256,  362,  359,  343,
 /*   830 */   886,  426,  408,  357,  905,  721,  228,  384,  227,   49,
 /*   840 */    50,  742,  722,  803,  965,  756,   51,  900,   28,  342,
 /*   850 */   113,  429,  675,  675,  248,  220,  333,  419,    4,  429,
 /*   860 */   289,  357,  808,  886,  314,  314,  229,  166,  262,   99,
 /*   870 */    99,  805,  201,  691,  963,  349,  963,   79,   79,  394,
 /*   880 */   207,  255,  334,  408,  801,  807,  807,  809,  810,  811,
 /*   890 */   812,  813,  427,  423,  803,  358,  794,  967,   21,  113,
 /*   900 */   381,  429,  130,  113,  950,  199,  403,  385,  674,  429,
 /*   910 */   148,  429,  329,  738,  382,  808,  675,  675,  737,   99,
 /*   920 */    99,  754,  805,  246,  221,  149,  421,   99,   99,   99,
 /*   930 */    99,  675,  675,  176,  421,  406,  807,  807,  809,  810,
 /*   940 */   811,  812,  813,  427,  423,   52,  874,  803,  967,   21,
 /*   950 */   297,  209,  429,  273,  126,  346,  403,  390,  130, 1238,
 /*   960 */  1238,  235,   49,   50,  403,  399,  403,  420,  874,   51,
 /*   970 */    99,   99,  326,  880,  772,  773,  421,  429,  755,  301,
 /*   980 */   419,    4,  797,  801,  421,  808,  421,  314,  314,  807,
 /*   990 */   807,  809,  810,  811,  812,   24,   24,  187,  186,  247,
 /*  1000 */   348,  311,  801,  429,  801,  388,  408,  403,  380,  294,
 /*  1010 */   429,  379,  429,  383,  711,  733,  733,  803,  179,   73,
 /*  1020 */   353,   24,   24,   23,   23,  675,  675,  421,   24,   24,
 /*  1030 */    26,   26,  806,  248,    2,  300,  429,  177,  755,  429,
 /*  1040 */   675,  675,  302,  303,  264,  805,  266,  898,  712,  298,
 /*  1050 */   113,  413,  421,  754,   99,   99,  429,   99,   99,  807,
 /*  1060 */   807,  809,  810,  811,  812,  813,  427,  423,  299,  184,
 /*  1070 */   310,  967,   21,  755,   24,   24,  727,  429,  421,  113,
 /*  1080 */   421,  754,  429,  268,  738,  421,  429,  421,  397,  737,
 /*  1090 */   429,  309,  962,  202,  395,   97,   97,  429,  241,  429,
 /*  1100 */    75,   75,  730,  754,   84,   84,  355,  429,   85,   85,
 /*  1110 */   429,  421,  878,  387,  421,   86,   86,   87,   87,  429,
 /*  1120 */   321,  203,  175,  429,  223,   88,   88,  429,   27,   27,
 /*  1130 */   799,  421,  177,  755,  219,  429,  754,   76,   76,  271,
 /*  1140 */   429,   78,   78,  906,  429,   89,   89,  754,  429,  356,
 /*  1150 */   164,  272,  421,   90,   90,  240,  156,  421,   91,   91,
 /*  1160 */   429,  421,   25,   25,  903,  421,   92,   92,  774,  775,
 /*  1170 */   429,  350,  421,  197,  421,  219,  875,  429,   93,   93,
 /*  1180 */   904,  429,  421,  689,  689,  421,  754,  724,   94,   94,
 /*  1190 */   905,  407,  234,  429,  421,   80,   80,  239,  421,   95,
 /*  1200 */    95,  238,  421,   10,  754,  410,  429,  920,  113,  918,
 /*  1210 */   421,   96,   96,  429,  414,  421,  352,  113,  868,  421,
 /*  1220 */   219,  910,   41,  421,   81,   81,  723,  428,  429,  735,
 /*  1230 */   429,  118,  118,   43,  367,  421,  429,  418,  223,  714,
 /*  1240 */   113,  908,  429,   41,  243,  421,  119,  119,  120,  120,
 /*  1250 */   919,  429,  421,  429,  103,  103,  421,  429,  713,  429,
 /*  1260 */    98,   98,   35,  172,  173,  429,  330,  429,  421,   83,
 /*  1270 */    83,  106,  106,  814,  814,  100,  100,  107,  107,  429,
 /*  1280 */   261,  421,  429,  105,  105,  117,  117,  296,  421,  429,
 /*  1290 */   704,  703,  331,  260,  429,  332,  429,  112,  112,  842,
 /*  1300 */   111,  111,  429,  421,  190,  421,  429,  110,  110,  789,
 /*  1310 */   337,  421,  108,  108,  109,  109,  237,  421,  946,  429,
 /*  1320 */   102,  102,   12,  764,  104,  104,  421,  219,  421,  429,
 /*  1330 */   339,  429,  421,  180,  421,  872,  245,  101,  101,  223,
 /*  1340 */   421,  895,  421,  354,  684,  894,  360,   74,   74,   77,
 /*  1350 */    77,  361,  897,  250,  421,  270,  667,  421,  254,  259,
 /*  1360 */     9,  762,  800,  744,  421,  409,  992,  873,  274,  421,
 /*  1370 */   280,  421,  165,  676,  665,  664,  666,  421,  293,  155,
 /*  1380 */   233,  421,  146,  135,  124,  137,   39,  785,  114,  340,
 /*  1390 */    30,  139,  345,  204,  421,  881,  242,  365,  205,  899,
 /*  1400 */   307,  212,  157,  363,  421,  141,  421,  213,  142,  214,
 /*  1410 */   115,  253,  373,  150,  796,  709,  694,  375,  378,  695,
 /*  1420 */   116,  258,  683,  708,  682,  393,   38,    8,   45,  412,
 /*  1430 */   416,  425,   68,  934,  752,  263,  398,   40,  396,  431,
 /*  1440 */   947,  281,  288,  753,  265,    5,  943,  751,  282,  230,
 /*  1450 */   267,  232,  945,   11,   70,  660,  316,  917,   13,  278,
 /*  1460 */   276,  750,  269,  734,  277,  279,   29,  132,  191,  322,
 /*  1470 */   193,  192,  324,  327,  196,  133,  167,  879,  198,  856,
 /*  1480 */   134,  200,  136,  795,  140,  222,  128,  138,  725,  884,
 /*  1490 */   219,  969,  143,  144,  893,  344,  147,   31,  145,   32,
 /*  1500 */    33,   34,  129,  892,  896,  210,   22,  208,   14,  249,
 /*  1510 */   211,  158,  670,  364,  260,  152,  368,  215,   15,   16,
 /*  1520 */   707,  371,   36,  172,  217,  173,  828,  125,  826,   37,
 /*  1530 */   732,  182,  854,   17,  820,  736,  218,    6,  758,  183,
 /*  1540 */   386,  185,  153,  424,  411,  867,  763,  178,   43,   18,
 /*  1550 */   160,   41,   19,  855,  853,  902,  405,  901,  858,  404,
 /*  1560 */   924,  925,  224,  161,  415,  857,  162,  430,  827,  225,
 /*  1570 */   661,  816,    3,  285,  933,  815,   54,  657,  226,  671,
 /*  1580 */  1257,  976,  976,  976,  843,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,  185,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   15,   16,   17,   18,
 /*    30 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*    40 */    29,   30,   47,  135,   49,  137,   49,   50,    5,    6,
 /*    50 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    60 */    17,   18,   39,   20,   21,   22,   23,   24,   25,   26,
 /*    70 */    27,   28,   29,   30,   77,  246,  247,  248,    5,    6,
 /*    80 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    90 */    17,   18,   97,   20,   21,   22,   23,   24,   25,   26,
 /*   100 */    27,   28,   29,   30,   81,   85,    7,   20,   21,   22,
 /*   110 */    23,   24,   25,   26,   27,   28,   29,   30,   57,   96,
 /*   120 */     7,   48,   30,   24,   25,  170,   65,    1,    2,   45,
 /*   130 */    31,   70,   75,   24,   25,   26,   27,   28,   29,   30,
 /*   140 */    67,   42,   43,  188,  189,  148,   47,   45,   49,   50,
 /*   150 */   170,  170,   91,   69,  170,  112,  113,  228,  177,  170,
 /*   160 */   179,  180,   54,  182,   56,  142,  211,   68,  187,  214,
 /*   170 */    86,   87,   64,  192,  196,  246,  247,  248,   79,  170,
 /*   180 */   225,  226,  204,   15,   16,   17,   18,  203,   20,   21,
 /*   190 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  210,
 /*   200 */   245,  164,  165,  166,  120,   92,  107,  150,  151,  152,
 /*   210 */   153,  154,  155,  156,  157,  158,  159,  160,  161,  162,
 /*   220 */   121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*   230 */   131,  132,  133,  134,    5,    6,    7,    8,    9,   10,
 /*   240 */    11,   12,   13,   14,   15,   16,   17,   18,  268,   20,
 /*   250 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   260 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   270 */    15,   16,   17,   18,  265,   20,   21,   22,   23,   24,
 /*   280 */    25,   26,   27,   28,   29,   30,    6,    7,    8,    9,
 /*   290 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   44,
 /*   300 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   310 */    30,   29,   30,   84,   26,   27,   28,   29,   30,    5,
 /*   320 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   330 */    16,   17,   18,   84,   20,   21,   22,   23,   24,   25,
 /*   340 */    26,   27,   28,   29,   30,  191,  167,  168,   44,  191,
 /*   350 */   171,  184,   48,   43,  175,  102,  103,   47,   44,   49,
 /*   360 */     9,   10,   11,   12,    5,    6,    7,    8,    9,   10,
 /*   370 */    11,   12,   13,   14,   15,   16,   17,   18,  170,   20,
 /*   380 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   390 */   211,  170,  195,  214,  197,  198,  188,  189,  207,  208,
 /*   400 */   246,  247,  248,   44,  246,  247,  248,   97,  184,    5,
 /*   410 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   420 */    16,   17,   18,   26,   20,   21,   22,   23,   24,   25,
 /*   430 */    26,   27,   28,   29,   30,  185,  196,  270,   80,   81,
 /*   440 */    82,  262,  263,  264,  204,  266,   49,   50,   44,  241,
 /*   450 */   242,  243,   94,  245,    5,    6,    7,    8,    9,   10,
 /*   460 */    11,   12,   13,   14,   15,   16,   17,   18,  267,   20,
 /*   470 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   480 */   181,  260,  186,  187,  185,  186,  187,  195,  192,  197,
 /*   490 */   198,  192,  196,   44,  270,  196,  246,  247,  248,    5,
 /*   500 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   510 */    16,   17,   18,  188,   20,   21,   22,   23,   24,   25,
 /*   520 */    26,   27,   28,   29,   30,    5,    6,    7,    8,    9,
 /*   530 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  237,
 /*   540 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   550 */    30,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   560 */    14,   15,   16,   17,   18,  188,   20,   21,   22,   23,
 /*   570 */    24,   25,   26,   27,   28,   29,   30,    5,    6,    7,
 /*   580 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   590 */    18,    7,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   600 */    28,   29,   30,    7,   80,   81,   82,  188,   49,   50,
 /*   610 */    24,   25,  207,  208,   30,  246,  247,  248,   94,   48,
 /*   620 */    24,   25,   45,  211,    7,  170,  214,   31,   44,   43,
 /*   630 */   136,  170,   48,   47,  179,  180,   77,  182,   42,   43,
 /*   640 */    44,   45,  187,   47,  181,   49,   50,  192,  185,  188,
 /*   650 */   189,  239,  106,  188,  211,   78,  136,  214,  212,  213,
 /*   660 */   231,   77,   78,   79,   68,   79,  254,   50,   84,   97,
 /*   670 */   224,  259,  229,  230,  170,   79,   92,    7,    8,    9,
 /*   680 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  118,
 /*   690 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   700 */    30,  212,  213,  107,  199,  244,  245,  121,  122,  123,
 /*   710 */   124,  125,  126,  224,  210,   49,   50,  121,  122,  123,
 /*   720 */   124,  125,  126,  127,  128,  129,   49,   50,  239,  133,
 /*   730 */   134,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   740 */    14,   15,   16,   17,   18,  184,   20,   21,   22,   23,
 /*   750 */    24,   25,   26,   27,   28,   29,   30,    5,    6,    7,
 /*   760 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   770 */    18,    7,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   780 */    28,   29,   30,  170,  107,  108,   49,   50,   24,   25,
 /*   790 */     1,   80,   81,   82,   83,   31,    7,   32,  199,   34,
 /*   800 */    35,   36,   37,   69,  170,   40,   42,   43,   35,   45,
 /*   810 */    45,   47,  170,   49,   50,  149,   88,   89,   90,   30,
 /*   820 */    86,   87,    7,  195,   51,  197,  198,  252,  253,   86,
 /*   830 */    87,  270,   68,  170,   61,   62,  102,  103,  217,   24,
 /*   840 */    25,   26,   69,   79,  107,  108,   31,  211,  227,  236,
 /*   850 */   214,  170,   49,   50,  120,  228,   91,   42,   43,  170,
 /*   860 */    95,  170,   47,  120,   49,   50,   77,   78,   79,  188,
 /*   870 */   189,  107,  238,   84,   47,  239,   49,  188,  189,  235,
 /*   880 */   238,   92,  117,   68,  170,  121,  122,  123,  124,  125,
 /*   890 */   126,  127,  128,  129,   79,  259,  211,  133,  134,  214,
 /*   900 */   211,  170,   45,  214,  181,  140,  225,  226,  185,  170,
 /*   910 */    43,  170,  147,   99,  225,   47,   49,   50,  104,  188,
 /*   920 */   189,  170,  107,  260,   97,   43,  245,  188,  189,  188,
 /*   930 */   189,   49,   50,  235,  245,  208,  121,  122,  123,  124,
 /*   940 */   125,  126,  127,  128,  129,    7,  170,   79,  133,  134,
 /*   950 */   236,  260,  170,  170,   53,  256,  225,  226,   45,  102,
 /*   960 */   103,  210,   24,   25,  225,  226,  225,  226,  170,   31,
 /*   970 */   188,  189,   71,   60,   73,   74,  245,  170,   48,  203,
 /*   980 */    42,   43,   69,  170,  245,   47,  245,   49,   50,  121,
 /*   990 */   122,  123,  124,  125,  126,  188,  189,  229,  230,   86,
 /*  1000 */    87,  203,  170,  170,  170,  170,   68,  225,  226,  202,
 /*  1010 */   170,   26,  170,   98,   59,  100,  101,   79,  255,   43,
 /*  1020 */   170,  188,  189,  188,  189,   49,   50,  245,  188,  189,
 /*  1030 */   188,  189,  170,  120,   43,  202,  170,  107,  108,  170,
 /*  1040 */    49,   50,  202,  201,  228,  107,  228,  211,   93,  236,
 /*  1050 */   214,  268,  245,  170,  188,  189,  170,  188,  189,  121,
 /*  1060 */   122,  123,  124,  125,  126,  127,  128,  129,  236,   44,
 /*  1070 */   236,  133,  134,   48,  188,  189,  211,  170,  245,  214,
 /*  1080 */   245,  170,  170,  228,   99,  245,  170,  245,  202,  104,
 /*  1090 */   170,  225,   48,  210,  225,  188,  189,  170,   39,  170,
 /*  1100 */   188,  189,  213,  170,  188,  189,    7,  170,  188,  189,
 /*  1110 */   170,  245,   44,  224,  245,  188,  189,  188,  189,  170,
 /*  1120 */    44,  210,  170,  170,   48,  188,  189,  170,  188,  189,
 /*  1130 */    44,  245,  107,  108,   48,  170,  170,  188,  189,  170,
 /*  1140 */   170,  188,  189,  210,  170,  188,  189,  170,  170,   50,
 /*  1150 */   106,  244,  245,  188,  189,   96,  215,  245,  188,  189,
 /*  1160 */   170,  245,  188,  189,   35,  245,  188,  189,  112,  113,
 /*  1170 */   170,   44,  245,  105,  245,   48,  210,  170,  188,  189,
 /*  1180 */    51,  170,  245,   49,   50,  245,  170,  210,  188,  189,
 /*  1190 */    61,   62,  170,  170,  245,  188,  189,  138,  245,  188,
 /*  1200 */   189,  142,  245,  216,  170,  211,  170,  170,  214,  170,
 /*  1210 */   245,  188,  189,  170,  211,  245,   44,  214,   44,  245,
 /*  1220 */    48,  170,   48,  245,  188,  189,  210,    7,  170,   44,
 /*  1230 */   170,  188,  189,   48,   44,  245,  170,  211,   48,   44,
 /*  1240 */   214,  170,  170,   48,  210,  245,  188,  189,  188,  189,
 /*  1250 */   170,  170,  245,  170,  188,  189,  245,  170,   44,  170,
 /*  1260 */   188,  189,   48,   86,   87,  170,  170,  170,  245,  188,
 /*  1270 */   189,  188,  189,   49,   50,  188,  189,  188,  189,  170,
 /*  1280 */    79,  245,  170,  188,  189,  188,  189,  170,  245,  170,
 /*  1290 */    78,   79,  170,   92,  170,  170,  170,  188,  189,   79,
 /*  1300 */   188,  189,  170,  245,   43,  245,  170,  188,  189,  219,
 /*  1310 */   232,  245,  188,  189,  188,  189,  232,  245,   44,  170,
 /*  1320 */   188,  189,   48,   44,  188,  189,  245,   48,  245,  170,
 /*  1330 */   170,  170,  245,  170,  245,   44,  261,  188,  189,   48,
 /*  1340 */   245,  170,  245,  261,  191,  170,  170,  188,  189,  188,
 /*  1350 */   189,  170,  219,  170,  245,  232,  170,  245,  170,  170,
 /*  1360 */   216,  170,  170,  170,  245,  251,  105,  170,  170,  245,
 /*  1370 */   218,  245,  216,  170,  170,  170,  170,  245,    9,   43,
 /*  1380 */   193,  245,   43,  240,    5,  206,  118,  219,  194,   41,
 /*  1390 */   135,  209,  144,  209,  245,  258,  257,   41,  176,  219,
 /*  1400 */    63,  176,  240,  193,  245,  209,  245,  176,  209,  176,
 /*  1410 */   194,  193,   85,  206,  206,  200,  197,   85,   85,  198,
 /*  1420 */   194,  193,  190,  200,  190,  110,   85,   43,  135,  193,
 /*  1430 */   193,   43,  116,  269,  234,  233,  111,  115,  114,   46,
 /*  1440 */   178,   45,  173,  234,  233,   43,   36,  234,  172,  169,
 /*  1450 */   233,  169,  174,  183,  183,    4,    3,   66,   43,  220,
 /*  1460 */   222,  234,  233,  223,  221,  219,   43,   43,   83,   66,
 /*  1470 */    38,   77,   82,   95,   77,   39,   14,   44,   43,  249,
 /*  1480 */    39,  139,  119,  103,   85,  250,   91,  106,   42,  143,
 /*  1490 */    48,  146,  143,   85,    1,  145,  119,   14,  106,   14,
 /*  1500 */    14,   14,   91,    1,   50,  105,  141,  109,   43,  138,
 /*  1510 */    85,   97,   42,    7,   92,   43,   66,   83,   43,   43,
 /*  1520 */    52,   66,   43,   86,   66,   87,   44,   58,   44,   48,
 /*  1530 */    99,  105,   44,   43,  106,   44,  109,   43,  108,   44,
 /*  1540 */    48,   44,   43,  126,   97,   44,   50,   43,   48,  109,
 /*  1550 */    43,   48,  109,   44,   44,   44,   48,   44,   60,   47,
 /*  1560 */    44,   44,   48,   43,   97,   44,   43,   14,   44,   43,
 /*  1570 */    33,   44,   43,   38,   44,   44,   43,    1,  105,   47,
 /*  1580 */     0,  271,  271,  271,   79,
};
#define YY_SHIFT_USE_DFLT (1585)
#define YY_SHIFT_COUNT    (435)
#define YY_SHIFT_MIN      (-92)
#define YY_SHIFT_MAX      (1580)
static const short yy_shift_ofst[] = {
 /*     0 */   126,  765,  596,   99,  764,  559,  938,  938,  938,  938,
 /*    10 */   938,  789,  559,  938,  938,  938,  938,  938,  938,  938,
 /*    20 */   938,  938,   84,   -5,   43,   43,  229,  229,  815,  938,
 /*    30 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    40 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    50 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    60 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    70 */   584,  734,  913,  857,   73,  255,  314,  359,  404,  449,
 /*    80 */   494,  520,  546,  572,  726,  726,  726,  726,  726,  726,
 /*    90 */   726,  726,  726,  726,  726,  726,  726,  726,  726,  726,
 /*   100 */   752,  726,  280,  670,  670,   11,  168,  168,  168,   87,
 /*   110 */   109,  288,  282,  253,   20,   20,   20,   92, 1585, 1585,
 /*   120 */  1585,   57,   57,   57,  773,  773,   -3,   23,  867,  867,
 /*   130 */   666,  113,  803,  803,  803,  577,  803,  803,  803,  803,
 /*   140 */   803,  803,  803,  803,  803,  803,  803,  803,  803,  803,
 /*   150 */   803,  113,  803,  803,  803,  803,  253,  102,  102,  249,
 /*   160 */   102,  102,  102,  249, 1585, 1585,  586,  868,  868,  868,
 /*   170 */   524,  901,   61,   61, 1025,  310,  677,  737, 1129,  743,
 /*   180 */   108,  882,  397,  827,  827,  827,  976,  930,  991,  915,
 /*   190 */   985,  803,  803,  803,  803,  803,  803,  803,  803,  803,
 /*   200 */   803,  571,  617,  617,  803,  803, 1099,  571,  803, 1099,
 /*   210 */   803,  803,  803,  803,  803,  803,  803, 1056,  803,  803,
 /*   220 */   617,  803,  -92,  803,  803,  814,  803, 1044,  814,  803,
 /*   230 */   803,  803,  803, 1369, 1336, 1339, 1379, 1268, 1348, 1348,
 /*   240 */  1348, 1348, 1255, 1248, 1356, 1268, 1339, 1379, 1379, 1356,
 /*   250 */  1336, 1356, 1356, 1369, 1336, 1337, 1327, 1332, 1369, 1336,
 /*   260 */  1337, 1333, 1333, 1315, 1341, 1315, 1341, 1315, 1341, 1315,
 /*   270 */  1341, 1384, 1293, 1336, 1336, 1388, 1316, 1325, 1322, 1324,
 /*   280 */  1268, 1393, 1396, 1402, 1410, 1410, 1585, 1585, 1585, 1059,
 /*   290 */   358,  711,  351,  728,  304, 1076, 1068, 1086, 1127, 1172,
 /*   300 */  1174, 1190, 1195, 1214, 1134, 1177, 1212,  955, 1201, 1185,
 /*   310 */  1279, 1291, 1220, 1224, 1261, 1274, 1451, 1453, 1391, 1415,
 /*   320 */  1423, 1385, 1424, 1403, 1394, 1390, 1432, 1397, 1378, 1436,
 /*   330 */  1433, 1435, 1462, 1342, 1441, 1380, 1363, 1395, 1381, 1399,
 /*   340 */  1446, 1346, 1442, 1349, 1345, 1350, 1408, 1493, 1392, 1377,
 /*   350 */  1483, 1485, 1486, 1487, 1411, 1454, 1398, 1400, 1502, 1365,
 /*   360 */  1465, 1425, 1371, 1414, 1470, 1506, 1422, 1434, 1472, 1450,
 /*   370 */  1475, 1476, 1455, 1437, 1468, 1438, 1479, 1458, 1469, 1482,
 /*   380 */  1484, 1488, 1481, 1431, 1490, 1491, 1494, 1492, 1426, 1495,
 /*   390 */  1497, 1496, 1427, 1499, 1430, 1500, 1440, 1503, 1443, 1501,
 /*   400 */  1509, 1510, 1428, 1500, 1511, 1512, 1508, 1513, 1504, 1498,
 /*   410 */  1516, 1507, 1447, 1514, 1517, 1520, 1467, 1514, 1521, 1523,
 /*   420 */  1524, 1526, 1527, 1529, 1530, 1417, 1531, 1533, 1505, 1473,
 /*   430 */  1532, 1553, 1535, 1537, 1576, 1580,
};
#define YY_REDUCE_USE_DFLT (-172)
#define YY_REDUCE_COUNT (288)
#define YY_REDUCE_MIN   (-171)
#define YY_REDUCE_MAX   (1282)
static const short yy_reduce_ofst[] = {
 /*     0 */    37,  179,  -45,  208,  689,  -19,  681,  731,  739,  741,
 /*    10 */   782,  299,  455,  807,  833,  840,  842,  866,  869,  886,
 /*    20 */   461,  907,  412,  -71,  154,  158, -171,  250,  835,  912,
 /*    30 */   916,  920,  927,  929,  937,  940,  949,  953,  957,  965,
 /*    40 */   970,  974,  978,  990, 1000, 1007, 1011, 1023, 1036, 1043,
 /*    50 */  1058, 1060, 1066, 1072, 1081, 1083, 1087, 1089, 1095, 1097,
 /*    60 */  1109, 1112, 1119, 1124, 1126, 1132, 1136, 1149, 1159, 1161,
 /*    70 */   296,  489,  636,  443,  369,  369,  369,  369,  369,  369,
 /*    80 */   369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
 /*    90 */   369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
 /*   100 */   369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
 /*   110 */   369,  369,  369,  446,  197,  292,  628,  369,  369,  369,
 /*   120 */   369,  167,  224,  561,  191,  405,    9,  575,  634,  642,
 /*   130 */   -20,  -22,  -16,  -11,  504,  685,  751,  883,  911,  933,
 /*   140 */   966,  977, 1016,  613, 1034,  221,  714,  663,  813,  832,
 /*   150 */   691,  240,  776,  834,  783,  798,  889,  836,  865,  463,
 /*   160 */   994, 1003, 1026,  723,  768,  621,  325,  377,  419,  465,
 /*   170 */   201,  302,  505,  599,  429,  627,  644,  698,  727,  699,
 /*   180 */   763,  850,  862,  816,  818,  855,  952,  429,  969,  941,
 /*   190 */   987, 1022, 1037, 1039, 1051, 1071, 1080, 1096, 1117, 1122,
 /*   200 */  1125, 1090, 1078, 1084, 1160, 1163, 1075, 1133, 1171, 1082,
 /*   210 */  1175, 1176, 1181, 1183, 1186, 1188, 1189, 1153, 1191, 1192,
 /*   220 */  1123, 1193, 1114, 1197, 1198, 1144,  862, 1152, 1156, 1203,
 /*   230 */  1204, 1205, 1206, 1194, 1187, 1143, 1179, 1168, 1182, 1184,
 /*   240 */  1196, 1199, 1137, 1139, 1222, 1180, 1162, 1207, 1208, 1225,
 /*   250 */  1210, 1231, 1233, 1216, 1218, 1215, 1219, 1221, 1226, 1228,
 /*   260 */  1223, 1232, 1234, 1200, 1202, 1209, 1211, 1213, 1217, 1227,
 /*   270 */  1229, 1230, 1235, 1236, 1237, 1164, 1240, 1238, 1243, 1239,
 /*   280 */  1246, 1262, 1269, 1276, 1280, 1282, 1270, 1271, 1278,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1258, 1238, 1238, 1291, 1238,  994, 1180, 1180, 1180, 1180,
 /*    10 */  1180,  994,  994, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    20 */  1138, 1138, 1238, 1062, 1093, 1093, 1007, 1007, 1291, 1291,
 /*    30 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    40 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    50 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    60 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*    70 */   994, 1291, 1238, 1066, 1099, 1291, 1291, 1291, 1181, 1182,
 /*    80 */  1291, 1291, 1135, 1291, 1208, 1110, 1109, 1108, 1107, 1076,
 /*    90 */  1105, 1097, 1101, 1181, 1177, 1178, 1176, 1139, 1134, 1182,
 /*   100 */  1291, 1100, 1148, 1161, 1147, 1157, 1167, 1158, 1150, 1149,
 /*   110 */  1151, 1152, 1153, 1291, 1013, 1013, 1013, 1154, 1164, 1163,
 /*   120 */  1162, 1291, 1291, 1291, 1291, 1291, 1291, 1187, 1291, 1291,
 /*   130 */  1291, 1033, 1291, 1291, 1291, 1238, 1291, 1291, 1291, 1291,
 /*   140 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   150 */  1291, 1033, 1291, 1291, 1291, 1291, 1291, 1238, 1238, 1007,
 /*   160 */  1238, 1238, 1238, 1007, 1066, 1057, 1291, 1291, 1291, 1291,
 /*   170 */  1291, 1291, 1291, 1291, 1291, 1062, 1291, 1291, 1291, 1291,
 /*   180 */  1202, 1291, 1291, 1062, 1062, 1062, 1291, 1064, 1291, 1046,
 /*   190 */  1056, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   200 */  1291, 1104, 1078, 1078, 1291, 1291, 1288, 1104, 1291, 1288,
 /*   210 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1093, 1291, 1291,
 /*   220 */  1078, 1291, 1179, 1291, 1291, 1056, 1291, 1063, 1056, 1291,
 /*   230 */  1291, 1291, 1291, 1019, 1188, 1115, 1036, 1104, 1043, 1043,
 /*   240 */  1043, 1043, 1207, 1206,  986, 1104, 1115, 1036, 1036,  986,
 /*   250 */  1188,  986,  986, 1019, 1188, 1027, 1010, 1009, 1019, 1188,
 /*   260 */  1027, 1034, 1034, 1082, 1077, 1082, 1077, 1082, 1077, 1082,
 /*   270 */  1077, 1183, 1291, 1188, 1188, 1291, 1098, 1083, 1096, 1094,
 /*   280 */  1104, 1291, 1265, 1291, 1261, 1261, 1272, 1272,  989, 1291,
 /*   290 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   300 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   310 */  1291, 1291, 1291, 1291, 1121, 1291, 1291,  976, 1291, 1291,
 /*   320 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1224, 1291,
 /*   330 */  1291, 1194, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   340 */  1291, 1291, 1205, 1204, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   350 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1287, 1291, 1291,
 /*   360 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   370 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   380 */  1291, 1291, 1291, 1048, 1291, 1291, 1291, 1278, 1291, 1291,
 /*   390 */  1291, 1291, 1291, 1291, 1291, 1095, 1291, 1084, 1291, 1291,
 /*   400 */  1291, 1291, 1291, 1285, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   410 */  1291, 1291, 1291, 1240, 1291, 1291, 1291, 1239, 1291, 1291,
 /*   420 */  1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291, 1291,
 /*   430 */  1291, 1291,  980, 1291, 1291, 1291,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
   49,  /*       UUID => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "UUID",        
  "ANY",           "CONSTRAINT",    "DEFAULT",       "NULL",        
  "PRIMARY",       "UNIQUE",        "CHECK",         "REFERENCES",  
  "AUTOINCR",      "ON",            "UPDATE",        "DELETE",      
  "SIMPLE",        "PARTIAL",       "FULL",          "SET",         
  "DEFERRABLE",    "IMMEDIATE",     "FOREIGN",       "DROP",        
  "VIEW",          "AS",            "UNION",         "ALL",         
  "EXCEPT",        "INTERSECT",     "SELECT",        "VALUES",      
  "DISTINCT",      "DOT",           "FROM",          "JOIN_KW",     
  "JOIN",          "BY",            "USING",         "ORDER",       
  "ASC",           "DESC",          "GROUP",         "HAVING",      
  "LIMIT",         "TRUNCATE",      "WHERE",         "INTO",        
  "INSERT",        "FLOAT",         "BLOB",          "FALSE",       
  "TRUE",          "UNKNOWN",       "INTEGER",       "VARIABLE",    
  "CAST",          "TRIM",          "LEADING",       "TRAILING",    
  "BOTH",          "CHAR",          "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "SESSION",     
  "PRAGMA",        "BEGIN",         "TRIGGER",       "OF",          
  "FOR",           "EACH",          "ROW",           "ALTER",       
  "COLUMN",        "RECURSIVE",     "TEXT",          "STRING_KW",   
  "SCALAR",        "BOOL",          "BOOLEAN",       "VARBINARY",   
  "VARCHAR",       "NUMBER",        "DOUBLE",        "INT",         
  "INTEGER_KW",    "UNSIGNED",      "DECIMAL",       "error",       
  "input",         "ecmd",          "explain",       "cmdx",        
  "cmd",           "savepoint_opt",  "nm",            "create_table",
  "create_table_args",  "with_opts",     "create_table_end",  "createkw",    
  "ifnotexists",   "columnlist",    "engine_opts",   "tcons",       
  "column_def",    "create_column_end",  "column_name_and_type",  "carglist",    
  "typedef",       "autoinc",       "ccons",         "cconsname",   
  "term",          "expr",          "onconf",        "sortorder",   
  "check_constraint_def",  "eidlist_opt",   "matcharg",      "refargs",     
  "defer_subclause",  "refact_update",  "refact_delete",  "refact",      
  "init_deferred_pred_opt",  "col_list_with_autoinc",  "sortlist",      "eidlist",     
  "defer_subclause_opt",  "index_onconf",  "orconf",        "resolvetype", 
  "raisetype",     "ifexists",      "fullname",      "select",      
  "selectnowith",  "oneselect",     "with",          "multiselect_op",
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "values",        "nexprlist",     "exprlist",      "sclp",        
  "as",            "seltablist",    "stl_prefix",    "joinop",      
  "indexed_opt",   "on_opt",        "using_opt",     "join_nm",     
  "idlist",        "enable",        "setlist",       "insert_cmd",  
  "idlist_opt",    "trim_operands",  "trim_from_clause",  "trim_specification",
  "expr_optional",  "type_func",     "likeop",        "between_op",  
  "in_op",         "paren_exprlist",  "case_exprlist",  "case_else",   
  "uniqueflag",    "trigger_decl",  "trigger_cmd_list",  "trigger_time",
  "trigger_event",  "foreach_clause",  "when_clause",   "trigger_cmd", 
  "trnm",          "tridxby",       "alter_table_start",  "alter_add_constraint",
  "alter_add_column",  "column_name",   "alter_column_def",  "unique_spec", 
  "wqlist",        "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "column_name_and_type ::= nm typedef",
 /*  17 */ "create_column_end ::= autoinc",
 /*  18 */ "nm ::= ID|INDEXED",
 /*  19 */ "cconsname ::= CONSTRAINT nm",
 /*  20 */ "cconsname ::=",
 /*  21 */ "ccons ::= DEFAULT term",
 /*  22 */ "ccons ::= DEFAULT LP expr RP",
 /*  23 */ "ccons ::= DEFAULT PLUS term",
 /*  24 */ "ccons ::= DEFAULT MINUS term",
 /*  25 */ "ccons ::= NULL onconf",
 /*  26 */ "ccons ::= NOT NULL onconf",
 /*  27 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  28 */ "ccons ::= cconsname UNIQUE",
 /*  29 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  30 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  31 */ "ccons ::= defer_subclause",
 /*  32 */ "ccons ::= COLLATE ID|INDEXED",
 /*  33 */ "autoinc ::=",
 /*  34 */ "autoinc ::= AUTOINCR",
 /*  35 */ "refargs ::= refact_update",
 /*  36 */ "refargs ::= refact_delete",
 /*  37 */ "refargs ::= refact_delete refact_update",
 /*  38 */ "refargs ::= refact_update refact_delete",
 /*  39 */ "refargs ::=",
 /*  40 */ "refact_update ::= ON UPDATE refact",
 /*  41 */ "refact_delete ::= ON DELETE refact",
 /*  42 */ "matcharg ::= MATCH SIMPLE",
 /*  43 */ "matcharg ::= MATCH PARTIAL",
 /*  44 */ "matcharg ::= MATCH FULL",
 /*  45 */ "matcharg ::=",
 /*  46 */ "refact ::= SET NULL",
 /*  47 */ "refact ::= SET DEFAULT",
 /*  48 */ "refact ::= CASCADE",
 /*  49 */ "refact ::= RESTRICT",
 /*  50 */ "refact ::= NO ACTION",
 /*  51 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  52 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "init_deferred_pred_opt ::=",
 /*  54 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  56 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  57 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  58 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  59 */ "defer_subclause_opt ::=",
 /*  60 */ "onconf ::=",
 /*  61 */ "onconf ::= ON CONFLICT resolvetype",
 /*  62 */ "orconf ::=",
 /*  63 */ "orconf ::= OR resolvetype",
 /*  64 */ "resolvetype ::= IGNORE",
 /*  65 */ "resolvetype ::= REPLACE",
 /*  66 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  67 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  68 */ "ifexists ::= IF EXISTS",
 /*  69 */ "ifexists ::=",
 /*  70 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  71 */ "cmd ::= select",
 /*  72 */ "select ::= with selectnowith",
 /*  73 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  74 */ "multiselect_op ::= UNION",
 /*  75 */ "multiselect_op ::= UNION ALL",
 /*  76 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  77 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  78 */ "values ::= VALUES LP nexprlist RP",
 /*  79 */ "values ::= values COMMA LP exprlist RP",
 /*  80 */ "distinct ::= DISTINCT",
 /*  81 */ "distinct ::= ALL",
 /*  82 */ "distinct ::=",
 /*  83 */ "sclp ::=",
 /*  84 */ "selcollist ::= sclp expr as",
 /*  85 */ "selcollist ::= sclp STAR",
 /*  86 */ "selcollist ::= sclp nm DOT STAR",
 /*  87 */ "as ::= AS nm",
 /*  88 */ "as ::=",
 /*  89 */ "from ::=",
 /*  90 */ "from ::= FROM seltablist",
 /*  91 */ "stl_prefix ::= seltablist joinop",
 /*  92 */ "stl_prefix ::=",
 /*  93 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  97 */ "fullname ::= nm",
 /*  98 */ "joinop ::= COMMA|JOIN",
 /*  99 */ "joinop ::= JOIN_KW JOIN",
 /* 100 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 102 */ "on_opt ::= ON expr",
 /* 103 */ "on_opt ::=",
 /* 104 */ "indexed_opt ::=",
 /* 105 */ "indexed_opt ::= INDEXED BY nm",
 /* 106 */ "indexed_opt ::= NOT INDEXED",
 /* 107 */ "using_opt ::= USING LP idlist RP",
 /* 108 */ "using_opt ::=",
 /* 109 */ "orderby_opt ::=",
 /* 110 */ "orderby_opt ::= ORDER BY sortlist",
 /* 111 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 112 */ "sortlist ::= expr sortorder",
 /* 113 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 114 */ "col_list_with_autoinc ::= expr autoinc",
 /* 115 */ "enable ::= ENABLE",
 /* 116 */ "enable ::= DISABLE",
 /* 117 */ "sortorder ::= ASC",
 /* 118 */ "sortorder ::= DESC",
 /* 119 */ "sortorder ::=",
 /* 120 */ "groupby_opt ::=",
 /* 121 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 122 */ "having_opt ::=",
 /* 123 */ "having_opt ::= HAVING expr",
 /* 124 */ "limit_opt ::=",
 /* 125 */ "limit_opt ::= LIMIT expr",
 /* 126 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 127 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 128 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 129 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 130 */ "where_opt ::=",
 /* 131 */ "where_opt ::= WHERE expr",
 /* 132 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 133 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 134 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 135 */ "setlist ::= nm EQ expr",
 /* 136 */ "setlist ::= LP idlist RP EQ expr",
 /* 137 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 139 */ "insert_cmd ::= INSERT orconf",
 /* 140 */ "insert_cmd ::= REPLACE",
 /* 141 */ "idlist_opt ::=",
 /* 142 */ "idlist_opt ::= LP idlist RP",
 /* 143 */ "idlist ::= idlist COMMA nm",
 /* 144 */ "idlist ::= nm",
 /* 145 */ "expr ::= LP expr RP",
 /* 146 */ "term ::= NULL",
 /* 147 */ "expr ::= ID|INDEXED",
 /* 148 */ "expr ::= JOIN_KW",
 /* 149 */ "expr ::= nm DOT nm",
 /* 150 */ "term ::= FLOAT|BLOB",
 /* 151 */ "term ::= STRING",
 /* 152 */ "term ::= FALSE",
 /* 153 */ "term ::= TRUE",
 /* 154 */ "term ::= UNKNOWN",
 /* 155 */ "term ::= INTEGER",
 /* 156 */ "expr ::= VARIABLE",
 /* 157 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 158 */ "expr ::= CAST LP expr AS typedef RP",
 /* 159 */ "expr ::= TRIM LP trim_operands RP",
 /* 160 */ "trim_operands ::= trim_from_clause expr",
 /* 161 */ "trim_operands ::= expr",
 /* 162 */ "trim_from_clause ::= expr FROM",
 /* 163 */ "trim_from_clause ::= trim_specification expr_optional FROM",
 /* 164 */ "expr_optional ::=",
 /* 165 */ "expr_optional ::= expr",
 /* 166 */ "trim_specification ::= LEADING",
 /* 167 */ "trim_specification ::= TRAILING",
 /* 168 */ "trim_specification ::= BOTH",
 /* 169 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 170 */ "expr ::= type_func LP distinct exprlist RP",
 /* 171 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 172 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 173 */ "expr ::= expr AND expr",
 /* 174 */ "expr ::= expr OR expr",
 /* 175 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 176 */ "expr ::= expr EQ|NE expr",
 /* 177 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 178 */ "expr ::= expr PLUS|MINUS expr",
 /* 179 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 180 */ "expr ::= expr CONCAT expr",
 /* 181 */ "likeop ::= LIKE_KW|MATCH",
 /* 182 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 183 */ "expr ::= expr likeop expr",
 /* 184 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 185 */ "expr ::= expr IS NULL",
 /* 186 */ "expr ::= expr IS NOT NULL",
 /* 187 */ "expr ::= NOT expr",
 /* 188 */ "expr ::= BITNOT expr",
 /* 189 */ "expr ::= MINUS expr",
 /* 190 */ "expr ::= PLUS expr",
 /* 191 */ "between_op ::= BETWEEN",
 /* 192 */ "between_op ::= NOT BETWEEN",
 /* 193 */ "expr ::= expr between_op expr AND expr",
 /* 194 */ "in_op ::= IN",
 /* 195 */ "in_op ::= NOT IN",
 /* 196 */ "expr ::= expr in_op LP exprlist RP",
 /* 197 */ "expr ::= LP select RP",
 /* 198 */ "expr ::= expr in_op LP select RP",
 /* 199 */ "expr ::= expr in_op nm paren_exprlist",
 /* 200 */ "expr ::= EXISTS LP select RP",
 /* 201 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 202 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 203 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 204 */ "case_else ::= ELSE expr",
 /* 205 */ "case_else ::=",
 /* 206 */ "exprlist ::=",
 /* 207 */ "nexprlist ::= nexprlist COMMA expr",
 /* 208 */ "nexprlist ::= expr",
 /* 209 */ "paren_exprlist ::=",
 /* 210 */ "paren_exprlist ::= LP exprlist RP",
 /* 211 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 212 */ "uniqueflag ::= UNIQUE",
 /* 213 */ "uniqueflag ::=",
 /* 214 */ "eidlist_opt ::=",
 /* 215 */ "eidlist_opt ::= LP eidlist RP",
 /* 216 */ "eidlist ::= eidlist COMMA nm",
 /* 217 */ "eidlist ::= nm",
 /* 218 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 219 */ "cmd ::= SET SESSION nm EQ term",
 /* 220 */ "cmd ::= PRAGMA nm",
 /* 221 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 222 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 223 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 224 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 225 */ "trigger_time ::= BEFORE",
 /* 226 */ "trigger_time ::= AFTER",
 /* 227 */ "trigger_time ::= INSTEAD OF",
 /* 228 */ "trigger_time ::=",
 /* 229 */ "trigger_event ::= DELETE|INSERT",
 /* 230 */ "trigger_event ::= UPDATE",
 /* 231 */ "trigger_event ::= UPDATE OF idlist",
 /* 232 */ "foreach_clause ::=",
 /* 233 */ "when_clause ::=",
 /* 234 */ "when_clause ::= WHEN expr",
 /* 235 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 236 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 237 */ "trnm ::= nm DOT nm",
 /* 238 */ "tridxby ::= INDEXED BY nm",
 /* 239 */ "tridxby ::= NOT INDEXED",
 /* 240 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 241 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 242 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 243 */ "trigger_cmd ::= select",
 /* 244 */ "expr ::= RAISE LP IGNORE RP",
 /* 245 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 246 */ "raisetype ::= ROLLBACK",
 /* 247 */ "raisetype ::= ABORT",
 /* 248 */ "raisetype ::= FAIL",
 /* 249 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 250 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 251 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 252 */ "alter_add_column ::= alter_table_start ADD column_name",
 /* 253 */ "column_name ::= COLUMN nm",
 /* 254 */ "column_name ::= nm",
 /* 255 */ "alter_column_def ::= alter_add_column typedef",
 /* 256 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 257 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 258 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 259 */ "unique_spec ::= UNIQUE",
 /* 260 */ "unique_spec ::= PRIMARY KEY",
 /* 261 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 262 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 263 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 264 */ "with ::=",
 /* 265 */ "with ::= WITH wqlist",
 /* 266 */ "with ::= WITH RECURSIVE wqlist",
 /* 267 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 268 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 269 */ "typedef ::= TEXT",
 /* 270 */ "typedef ::= STRING_KW",
 /* 271 */ "typedef ::= SCALAR",
 /* 272 */ "typedef ::= BOOL",
 /* 273 */ "typedef ::= BOOLEAN",
 /* 274 */ "typedef ::= VARBINARY",
 /* 275 */ "typedef ::= UUID",
 /* 276 */ "char_len ::= LP INTEGER RP",
 /* 277 */ "typedef ::= VARCHAR char_len",
 /* 278 */ "number_typedef ::= NUMBER",
 /* 279 */ "number_typedef ::= DOUBLE",
 /* 280 */ "number_typedef ::= INT|INTEGER_KW",
 /* 281 */ "number_typedef ::= UNSIGNED",
 /* 282 */ "number_typedef ::= DECIMAL",
 /* 283 */ "input ::= ecmd",
 /* 284 */ "explain ::=",
 /* 285 */ "cmdx ::= cmd",
 /* 286 */ "savepoint_opt ::= SAVEPOINT",
 /* 287 */ "savepoint_opt ::=",
 /* 288 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 289 */ "create_table_args ::= LP columnlist RP",
 /* 290 */ "with_opts ::= WITH engine_opts",
 /* 291 */ "with_opts ::=",
 /* 292 */ "columnlist ::= columnlist COMMA tcons",
 /* 293 */ "columnlist ::= columnlist COMMA column_def create_column_end",
 /* 294 */ "columnlist ::= column_def create_column_end",
 /* 295 */ "column_def ::= column_name_and_type carglist",
 /* 296 */ "columnlist ::= tcons",
 /* 297 */ "carglist ::= carglist ccons",
 /* 298 */ "carglist ::=",
 /* 299 */ "ccons ::= check_constraint_def",
 /* 300 */ "tcons ::= check_constraint_def",
 /* 301 */ "defer_subclause_opt ::= defer_subclause",
 /* 302 */ "resolvetype ::= raisetype",
 /* 303 */ "selectnowith ::= oneselect",
 /* 304 */ "oneselect ::= values",
 /* 305 */ "sclp ::= selcollist COMMA",
 /* 306 */ "as ::= ID|STRING",
 /* 307 */ "join_nm ::= ID|INDEXED",
 /* 308 */ "join_nm ::= JOIN_KW",
 /* 309 */ "expr ::= term",
 /* 310 */ "type_func ::= CHAR",
 /* 311 */ "exprlist ::= nexprlist",
 /* 312 */ "foreach_clause ::= FOR EACH ROW",
 /* 313 */ "trnm ::= nm",
 /* 314 */ "tridxby ::=",
 /* 315 */ "cmd ::= alter_column_def carglist create_column_end",
 /* 316 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 188: /* term */
    case 189: /* expr */
{
#line 962 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy146).pExpr, false);
#line 1593 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 193: /* eidlist_opt */
    case 201: /* col_list_with_autoinc */
    case 202: /* sortlist */
    case 203: /* eidlist */
    case 217: /* selcollist */
    case 220: /* groupby_opt */
    case 222: /* orderby_opt */
    case 225: /* nexprlist */
    case 226: /* exprlist */
    case 227: /* sclp */
    case 238: /* setlist */
    case 249: /* paren_exprlist */
    case 250: /* case_exprlist */
{
#line 1516 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy126));
#line 1612 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 210: /* fullname */
    case 218: /* from */
    case 229: /* seltablist */
    case 230: /* stl_prefix */
{
#line 711 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy27));
#line 1622 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 211: /* select */
    case 212: /* selectnowith */
    case 213: /* oneselect */
    case 224: /* values */
{
#line 473 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy497));
#line 1632 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 214: /* with */
    case 268: /* wqlist */
{
#line 1814 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy79));
#line 1640 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 219: /* where_opt */
    case 221: /* having_opt */
    case 233: /* on_opt */
    case 251: /* case_else */
    case 258: /* when_clause */
{
#line 871 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy60), false);
#line 1651 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 234: /* using_opt */
    case 236: /* idlist */
    case 240: /* idlist_opt */
{
#line 754 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy200));
#line 1660 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 241: /* trim_operands */
    case 242: /* trim_from_clause */
{
#line 1133 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy465));
#line 1668 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 244: /* expr_optional */
{
#line 1164 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy71), false);
#line 1675 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 254: /* trigger_cmd_list */
    case 259: /* trigger_cmd */
{
#line 1615 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy93));
#line 1683 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
    case 256: /* trigger_event */
{
#line 1596 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy466).b);
#line 1690 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1866 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 165, 3 },
  { 165, 1 },
  { 166, 1 },
  { 166, 3 },
  { 168, 2 },
  { 168, 1 },
  { 168, 1 },
  { 168, 2 },
  { 168, 3 },
  { 168, 4 },
  { 171, 4 },
  { 175, 1 },
  { 176, 0 },
  { 176, 3 },
  { 178, 3 },
  { 174, 0 },
  { 182, 2 },
  { 181, 1 },
  { 170, 1 },
  { 187, 2 },
  { 187, 0 },
  { 186, 2 },
  { 186, 4 },
  { 186, 3 },
  { 186, 3 },
  { 186, 2 },
  { 186, 3 },
  { 186, 4 },
  { 186, 2 },
  { 192, 5 },
  { 186, 6 },
  { 186, 1 },
  { 186, 2 },
  { 185, 0 },
  { 185, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 2 },
  { 195, 2 },
  { 195, 0 },
  { 197, 3 },
  { 198, 3 },
  { 194, 2 },
  { 194, 2 },
  { 194, 2 },
  { 194, 0 },
  { 199, 2 },
  { 199, 2 },
  { 199, 1 },
  { 199, 1 },
  { 199, 2 },
  { 196, 3 },
  { 196, 2 },
  { 200, 0 },
  { 200, 2 },
  { 200, 2 },
  { 179, 6 },
  { 179, 5 },
  { 179, 12 },
  { 204, 0 },
  { 190, 0 },
  { 190, 3 },
  { 206, 0 },
  { 206, 2 },
  { 207, 1 },
  { 207, 1 },
  { 168, 4 },
  { 168, 4 },
  { 209, 2 },
  { 209, 0 },
  { 168, 7 },
  { 168, 1 },
  { 211, 2 },
  { 212, 3 },
  { 215, 1 },
  { 215, 2 },
  { 215, 1 },
  { 213, 9 },
  { 224, 4 },
  { 224, 5 },
  { 216, 1 },
  { 216, 1 },
  { 216, 0 },
  { 227, 0 },
  { 217, 3 },
  { 217, 2 },
  { 217, 4 },
  { 228, 2 },
  { 228, 0 },
  { 218, 0 },
  { 218, 2 },
  { 230, 2 },
  { 230, 0 },
  { 229, 6 },
  { 229, 8 },
  { 229, 7 },
  { 229, 7 },
  { 210, 1 },
  { 231, 1 },
  { 231, 2 },
  { 231, 3 },
  { 231, 4 },
  { 233, 2 },
  { 233, 0 },
  { 232, 0 },
  { 232, 3 },
  { 232, 2 },
  { 234, 4 },
  { 234, 0 },
  { 222, 0 },
  { 222, 3 },
  { 202, 4 },
  { 202, 2 },
  { 201, 4 },
  { 201, 2 },
  { 237, 1 },
  { 237, 1 },
  { 191, 1 },
  { 191, 1 },
  { 191, 0 },
  { 220, 0 },
  { 220, 3 },
  { 221, 0 },
  { 221, 2 },
  { 223, 0 },
  { 223, 2 },
  { 223, 4 },
  { 223, 4 },
  { 168, 6 },
  { 168, 3 },
  { 219, 0 },
  { 219, 2 },
  { 168, 8 },
  { 238, 5 },
  { 238, 7 },
  { 238, 3 },
  { 238, 5 },
  { 168, 6 },
  { 168, 7 },
  { 239, 2 },
  { 239, 1 },
  { 240, 0 },
  { 240, 3 },
  { 236, 3 },
  { 236, 1 },
  { 189, 3 },
  { 188, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 3 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 189, 1 },
  { 189, 3 },
  { 189, 6 },
  { 189, 4 },
  { 241, 2 },
  { 241, 1 },
  { 242, 2 },
  { 242, 3 },
  { 244, 0 },
  { 244, 1 },
  { 243, 1 },
  { 243, 1 },
  { 243, 1 },
  { 189, 5 },
  { 189, 5 },
  { 189, 4 },
  { 189, 5 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 246, 1 },
  { 246, 2 },
  { 189, 3 },
  { 189, 5 },
  { 189, 3 },
  { 189, 4 },
  { 189, 2 },
  { 189, 2 },
  { 189, 2 },
  { 189, 2 },
  { 247, 1 },
  { 247, 2 },
  { 189, 5 },
  { 248, 1 },
  { 248, 2 },
  { 189, 5 },
  { 189, 3 },
  { 189, 5 },
  { 189, 4 },
  { 189, 4 },
  { 189, 5 },
  { 250, 5 },
  { 250, 4 },
  { 251, 2 },
  { 251, 0 },
  { 226, 0 },
  { 225, 3 },
  { 225, 1 },
  { 249, 0 },
  { 249, 3 },
  { 168, 10 },
  { 252, 1 },
  { 252, 0 },
  { 193, 0 },
  { 193, 3 },
  { 203, 3 },
  { 203, 1 },
  { 168, 6 },
  { 168, 5 },
  { 168, 2 },
  { 168, 5 },
  { 168, 7 },
  { 168, 5 },
  { 253, 9 },
  { 255, 1 },
  { 255, 1 },
  { 255, 2 },
  { 255, 0 },
  { 256, 1 },
  { 256, 1 },
  { 256, 3 },
  { 257, 0 },
  { 258, 0 },
  { 258, 2 },
  { 254, 3 },
  { 254, 2 },
  { 260, 3 },
  { 261, 3 },
  { 261, 2 },
  { 259, 7 },
  { 259, 5 },
  { 259, 5 },
  { 259, 1 },
  { 189, 4 },
  { 189, 6 },
  { 208, 1 },
  { 208, 1 },
  { 208, 1 },
  { 168, 4 },
  { 262, 3 },
  { 263, 4 },
  { 264, 3 },
  { 265, 2 },
  { 265, 1 },
  { 266, 2 },
  { 168, 12 },
  { 168, 5 },
  { 168, 5 },
  { 267, 1 },
  { 267, 2 },
  { 168, 4 },
  { 168, 6 },
  { 168, 5 },
  { 214, 0 },
  { 214, 2 },
  { 214, 3 },
  { 268, 6 },
  { 268, 8 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 269, 3 },
  { 184, 2 },
  { 270, 1 },
  { 270, 1 },
  { 270, 1 },
  { 270, 1 },
  { 270, 1 },
  { 164, 1 },
  { 166, 0 },
  { 167, 1 },
  { 169, 1 },
  { 169, 0 },
  { 168, 4 },
  { 172, 3 },
  { 173, 2 },
  { 173, 0 },
  { 177, 3 },
  { 177, 4 },
  { 177, 2 },
  { 180, 2 },
  { 177, 1 },
  { 183, 2 },
  { 183, 0 },
  { 186, 1 },
  { 179, 1 },
  { 204, 1 },
  { 207, 1 },
  { 212, 1 },
  { 213, 1 },
  { 227, 2 },
  { 228, 1 },
  { 235, 1 },
  { 235, 1 },
  { 189, 1 },
  { 245, 1 },
  { 226, 1 },
  { 257, 3 },
  { 260, 1 },
  { 261, 0 },
  { 168, 3 },
  { 184, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2326 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2334 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2339 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2344 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2349 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2354 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2359 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2366 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2373 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2380 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy82);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2391 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 189 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2396 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 33: /* autoinc ::= */ yytestcase(yyruleno==33);
      case 53: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==53);
      case 59: /* defer_subclause_opt ::= */ yytestcase(yyruleno==59);
      case 69: /* ifexists ::= */ yytestcase(yyruleno==69);
      case 82: /* distinct ::= */ yytestcase(yyruleno==82);
#line 192 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy82 = 0;}
#line 2406 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 193 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy82 = 1;}
#line 2411 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 200 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2432 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 218 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2437 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 16: /* column_name_and_type ::= nm typedef */
#line 236 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, NULL, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy58);
  sql_create_column_start(pParse);
}
#line 2445 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 17: /* create_column_end ::= autoinc */
#line 241 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_column_def.space->def->field_count - 1;
  if (yymsp[0].minor.yy82 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
  if (pParse->create_table_def.new_space == NULL)
    sql_create_column_end(pParse);
}
#line 2456 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 18: /* nm ::= ID|INDEXED */
#line 283 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2467 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 19: /* cconsname ::= CONSTRAINT nm */
#line 299 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy193 = yymsp[0].minor.yy0; }
#line 2472 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= */
#line 300 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[1].minor.yy193 = Token_nil; }
#line 2477 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 21: /* ccons ::= DEFAULT term */
      case 23: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==23);
#line 301 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy146);}
#line 2483 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT LP expr RP */
#line 302 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy146);}
#line 2488 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 24: /* ccons ::= DEFAULT MINUS term */
#line 304 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy146.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy146.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2499 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= NULL onconf */
#line 315 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy82 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy82);
}
#line 2509 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NOT NULL onconf */
#line 321 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy82);}
#line 2514 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 322 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy193, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy82, false);
  sqlAddPrimaryKey(pParse);
}
#line 2523 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname UNIQUE */
#line 327 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy193, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2533 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 29: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 336 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy193, &yymsp[-1].minor.yy146);
  sql_create_check_contraint(pParse);
}
#line 2541 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 30: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 341 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy193, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy126, yymsp[-1].minor.yy82, yymsp[0].minor.yy82,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2550 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= defer_subclause */
#line 346 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy82);}
#line 2555 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= COLLATE ID|INDEXED */
#line 347 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2560 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 34: /* autoinc ::= AUTOINCR */
#line 352 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = 1;}
#line 2565 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 35: /* refargs ::= refact_update */
#line 360 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yylhsminor.yy82 = (yymsp[0].minor.yy82 << 8); }
#line 2570 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 36: /* refargs ::= refact_delete */
#line 361 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yylhsminor.yy82 = yymsp[0].minor.yy82; }
#line 2576 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 37: /* refargs ::= refact_delete refact_update */
#line 362 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yylhsminor.yy82 = (yymsp[0].minor.yy82 << 8) | (yymsp[-1].minor.yy82) ; }
#line 2582 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-1].minor.yy82 = yylhsminor.yy82;
        break;
      case 38: /* refargs ::= refact_update refact_delete */
#line 363 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yylhsminor.yy82 = (yymsp[-1].minor.yy82 << 8) | (yymsp[0].minor.yy82) ; }
#line 2588 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-1].minor.yy82 = yylhsminor.yy82;
        break;
      case 39: /* refargs ::= */
#line 364 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[1].minor.yy82 = 0; }
#line 2594 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 40: /* refact_update ::= ON UPDATE refact */
      case 41: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==41);
#line 367 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-2].minor.yy82 = yymsp[0].minor.yy82; }
#line 2600 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 42: /* matcharg ::= MATCH SIMPLE */
#line 372 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = FKEY_MATCH_SIMPLE; }
#line 2605 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH PARTIAL */
#line 373 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = FKEY_MATCH_PARTIAL; }
#line 2610 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH FULL */
#line 374 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = FKEY_MATCH_FULL; }
#line 2615 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= */
#line 375 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[1].minor.yy82 = FKEY_MATCH_SIMPLE; }
#line 2620 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 46: /* refact ::= SET NULL */
#line 378 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = FKEY_ACTION_SET_NULL; }
#line 2625 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET DEFAULT */
#line 379 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = FKEY_ACTION_SET_DEFAULT; }
#line 2630 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= CASCADE */
#line 380 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy82 = FKEY_ACTION_CASCADE; }
#line 2635 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= RESTRICT */
#line 381 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy82 = FKEY_ACTION_RESTRICT; }
#line 2640 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= NO ACTION */
#line 382 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = FKEY_NO_ACTION; }
#line 2645 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 51: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 384 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy82 = 0;}
#line 2650 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 63: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==63);
      case 139: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==139);
#line 385 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy82 = yymsp[0].minor.yy82;}
#line 2657 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 54: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 68: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==68);
      case 192: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==192);
      case 195: /* in_op ::= NOT IN */ yytestcase(yyruleno==195);
#line 388 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy82 = 1;}
#line 2665 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 389 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy82 = 0;}
#line 2670 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 56: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 391 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy193, yymsp[-1].minor.yy126,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2679 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 396 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy193, yymsp[-1].minor.yy126,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2689 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 404 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy193, yymsp[-7].minor.yy126, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy126, yymsp[-2].minor.yy82, yymsp[-1].minor.yy82, yymsp[0].minor.yy82);
  sql_create_foreign_key(pParse);
}
#line 2697 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 60: /* onconf ::= */
#line 419 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy82 = ON_CONFLICT_ACTION_ABORT;}
#line 2702 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= ON CONFLICT resolvetype */
#line 420 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy82 = yymsp[0].minor.yy82;}
#line 2707 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 62: /* orconf ::= */
#line 421 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy82 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2712 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 64: /* resolvetype ::= IGNORE */
#line 424 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = ON_CONFLICT_ACTION_IGNORE;}
#line 2717 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= REPLACE */
      case 140: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==140);
#line 425 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = ON_CONFLICT_ACTION_REPLACE;}
#line 2723 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 66: /* cmd ::= DROP TABLE ifexists fullname */
#line 430 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy27, &t, yymsp[-1].minor.yy82);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2733 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP VIEW ifexists fullname */
#line 437 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy27, &t, yymsp[-1].minor.yy82);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2743 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 70: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 451 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy126, yymsp[0].minor.yy497, yymsp[-4].minor.yy82);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy497);
  }
}
#line 2756 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= select */
#line 463 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy497, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy497);
  sql_select_delete(pParse->db, yymsp[0].minor.yy497);
}
#line 2768 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 72: /* select ::= with selectnowith */
#line 506 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy497;
  if( p ){
    p->pWith = yymsp[-1].minor.yy79;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy79);
  }
  yymsp[-1].minor.yy497 = p; /*A-overwrites-W*/
}
#line 2782 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 73: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 519 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy497;
  Select *pLhs = yymsp[-2].minor.yy497;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy82;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy82!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy497 = pRhs;
}
#line 2808 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 74: /* multiselect_op ::= UNION */
      case 76: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==76);
#line 542 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2814 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION ALL */
#line 543 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy82 = TK_ALL;}
#line 2819 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 77: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 547 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy36.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy126);
  yymsp[-8].minor.yy497 = sqlSelectNew(pParse,yymsp[-6].minor.yy126,yymsp[-5].minor.yy27,yymsp[-4].minor.yy60,yymsp[-3].minor.yy126,yymsp[-2].minor.yy60,yymsp[-1].minor.yy126,yymsp[-7].minor.yy82,yymsp[0].minor.yy36.pLimit,yymsp[0].minor.yy36.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy497!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy497->zSelName), yymsp[-8].minor.yy497->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy497->zSelName), yymsp[-8].minor.yy497->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2855 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 78: /* values ::= VALUES LP nexprlist RP */
#line 583 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy497 = sqlSelectNew(pParse,yymsp[-1].minor.yy126,0,0,0,0,0,SF_Values,0,0);
}
#line 2862 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 79: /* values ::= values COMMA LP exprlist RP */
#line 586 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy497;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy126,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy497 = pRight;
  }else{
    yymsp[-4].minor.yy497 = pLeft;
  }
}
#line 2878 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 80: /* distinct ::= DISTINCT */
#line 603 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = SF_Distinct;}
#line 2883 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= ALL */
#line 604 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = SF_All;}
#line 2888 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 83: /* sclp ::= */
      case 109: /* orderby_opt ::= */ yytestcase(yyruleno==109);
      case 120: /* groupby_opt ::= */ yytestcase(yyruleno==120);
      case 206: /* exprlist ::= */ yytestcase(yyruleno==206);
      case 209: /* paren_exprlist ::= */ yytestcase(yyruleno==209);
      case 214: /* eidlist_opt ::= */ yytestcase(yyruleno==214);
#line 617 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy126 = 0;}
#line 2898 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 84: /* selcollist ::= sclp expr as */
#line 618 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy126 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy126, yymsp[-1].minor.yy146.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy126, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy126,&yymsp[-1].minor.yy146);
}
#line 2907 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp STAR */
#line 623 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy126 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy126, p);
}
#line 2919 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp nm DOT STAR */
#line 631 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy126 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy126, pDot);
}
#line 2933 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 87: /* as ::= AS nm */
#line 646 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2938 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 88: /* as ::= */
#line 648 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2943 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 89: /* from ::= */
#line 660 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy27 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy27));}
#line 2948 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 90: /* from ::= FROM seltablist */
#line 661 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy27 = yymsp[0].minor.yy27;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy27);
}
#line 2956 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 91: /* stl_prefix ::= seltablist joinop */
#line 669 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy27 && yymsp[-1].minor.yy27->nSrc>0) ) yymsp[-1].minor.yy27->a[yymsp[-1].minor.yy27->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy82;
}
#line 2963 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= */
#line 672 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy27 = 0;}
#line 2968 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 674 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy27 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy27,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy60,yymsp[0].minor.yy200);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy27, &yymsp[-2].minor.yy0);
}
#line 2976 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy27 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy27,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy60,yymsp[0].minor.yy200);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy27, yymsp[-4].minor.yy126);
}
#line 2984 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 684 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy27 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy27,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy497,yymsp[-1].minor.yy60,yymsp[0].minor.yy200);
}
#line 2991 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 688 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy27==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy60==0 && yymsp[0].minor.yy200==0 ){
    yymsp[-6].minor.yy27 = yymsp[-4].minor.yy27;
  }else if( yymsp[-4].minor.yy27->nSrc==1 ){
    yymsp[-6].minor.yy27 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy27,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy60,yymsp[0].minor.yy200);
    if( yymsp[-6].minor.yy27 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy27->a[yymsp[-6].minor.yy27->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy27->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy27);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy27);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy27,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy27 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy27,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy60,yymsp[0].minor.yy200);
  }
}
#line 3016 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 97: /* fullname ::= nm */
#line 712 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  /* yylhsminor.yy27-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy27 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy27 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3028 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy27 = yylhsminor.yy27;
        break;
      case 98: /* joinop ::= COMMA|JOIN */
#line 725 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy82 = JT_INNER; }
#line 3034 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW JOIN */
#line 727 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy82 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3039 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW join_nm JOIN */
#line 729 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy82 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3044 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 731 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-3].minor.yy82 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3049 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 102: /* on_opt ::= ON expr */
      case 123: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==131);
      case 204: /* case_else ::= ELSE expr */ yytestcase(yyruleno==204);
#line 735 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy60 = yymsp[0].minor.yy146.pExpr;}
#line 3057 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= */
      case 122: /* having_opt ::= */ yytestcase(yyruleno==122);
      case 130: /* where_opt ::= */ yytestcase(yyruleno==130);
      case 205: /* case_else ::= */ yytestcase(yyruleno==205);
#line 736 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy60 = 0;}
#line 3065 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 104: /* indexed_opt ::= */
#line 749 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3070 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= INDEXED BY nm */
#line 750 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3075 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= NOT INDEXED */
#line 751 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3080 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 107: /* using_opt ::= USING LP idlist RP */
#line 755 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-3].minor.yy200 = yymsp[-1].minor.yy200;}
#line 3085 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= */
      case 141: /* idlist_opt ::= */ yytestcase(yyruleno==141);
#line 756 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy200 = 0;}
#line 3091 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 110: /* orderby_opt ::= ORDER BY sortlist */
      case 121: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==121);
#line 770 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy126 = yymsp[0].minor.yy126;}
#line 3097 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 111: /* sortlist ::= sortlist COMMA expr sortorder */
#line 771 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy126 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy126,yymsp[-1].minor.yy146.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy126,yymsp[0].minor.yy82);
}
#line 3105 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= expr sortorder */
#line 775 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  /* yylhsminor.yy126-overwrites-yymsp[-1].minor.yy146. */
  yylhsminor.yy126 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy146.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy126,yymsp[0].minor.yy82);
}
#line 3114 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-1].minor.yy126 = yylhsminor.yy126;
        break;
      case 113: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 789 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy82 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy146.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy126 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy126, yymsp[-1].minor.yy146.pExpr);
}
#line 3129 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 114: /* col_list_with_autoinc ::= expr autoinc */
#line 800 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy82 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy146.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy126-overwrites-yymsp[-1].minor.yy146. */
  yylhsminor.yy126 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy146.pExpr);
}
#line 3144 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-1].minor.yy126 = yylhsminor.yy126;
        break;
      case 115: /* enable ::= ENABLE */
#line 813 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy28 = true;}
#line 3150 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 116: /* enable ::= DISABLE */
#line 814 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy28 = false;}
#line 3155 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 117: /* sortorder ::= ASC */
#line 818 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = SORT_ORDER_ASC;}
#line 3160 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= DESC */
#line 819 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = SORT_ORDER_DESC;}
#line 3165 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= */
#line 820 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy82 = SORT_ORDER_UNDEF;}
#line 3170 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 124: /* limit_opt ::= */
#line 845 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy36.pLimit = 0; yymsp[1].minor.yy36.pOffset = 0;}
#line 3175 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= LIMIT expr */
#line 846 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy36.pLimit = yymsp[0].minor.yy146.pExpr; yymsp[-1].minor.yy36.pOffset = 0;}
#line 3180 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 848 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-3].minor.yy36.pLimit = yymsp[-2].minor.yy146.pExpr; yymsp[-3].minor.yy36.pOffset = yymsp[0].minor.yy146.pExpr;}
#line 3185 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr COMMA expr */
#line 850 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-3].minor.yy36.pOffset = yymsp[-2].minor.yy146.pExpr; yymsp[-3].minor.yy36.pLimit = yymsp[0].minor.yy146.pExpr;}
#line 3190 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 128: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 854 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy79, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy27, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy27,yymsp[0].minor.yy60);
}
#line 3202 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= TRUNCATE TABLE fullname */
#line 865 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy27);
}
#line 3210 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 132: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 879 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy79, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy27, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy126 != NULL && yymsp[-1].minor.yy126->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy126->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy27,yymsp[-1].minor.yy126,yymsp[0].minor.yy60,yymsp[-5].minor.yy82);
}
#line 3227 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 133: /* setlist ::= setlist COMMA nm EQ expr */
#line 896 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy126 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy126, yymsp[0].minor.yy146.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy126, &yymsp[-2].minor.yy0, 1);
}
#line 3235 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 900 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy126 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy126, yymsp[-3].minor.yy200, yymsp[0].minor.yy146.pExpr);
}
#line 3242 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= nm EQ expr */
#line 903 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy126 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy146.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy126, &yymsp[-2].minor.yy0, 1);
}
#line 3250 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-2].minor.yy126 = yylhsminor.yy126;
        break;
      case 136: /* setlist ::= LP idlist RP EQ expr */
#line 907 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy126 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy200, yymsp[0].minor.yy146.pExpr);
}
#line 3258 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 137: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 913 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy79, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy27, yymsp[0].minor.yy497, yymsp[-1].minor.yy200, yymsp[-4].minor.yy82);
}
#line 3269 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 921 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy79, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy27, 0, yymsp[-2].minor.yy200, yymsp[-5].minor.yy82);
}
#line 3280 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 142: /* idlist_opt ::= LP idlist RP */
#line 939 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy200 = yymsp[-1].minor.yy200;}
#line 3285 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 143: /* idlist ::= idlist COMMA nm */
#line 940 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy200 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy200,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy200 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3296 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= nm */
#line 947 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  /* yylhsminor.yy200-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy200 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy200 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3308 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy200 = yylhsminor.yy200;
        break;
      case 145: /* expr ::= LP expr RP */
#line 1050 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy146,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy146.pExpr = yymsp[-1].minor.yy146.pExpr;}
#line 3314 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 146: /* term ::= NULL */
      case 150: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==150);
      case 151: /* term ::= STRING */ yytestcase(yyruleno==151);
      case 152: /* term ::= FALSE */ yytestcase(yyruleno==152);
      case 153: /* term ::= TRUE */ yytestcase(yyruleno==153);
      case 154: /* term ::= UNKNOWN */ yytestcase(yyruleno==154);
#line 1051 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy146,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3324 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 147: /* expr ::= ID|INDEXED */
      case 148: /* expr ::= JOIN_KW */ yytestcase(yyruleno==148);
#line 1052 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy146,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3330 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 149: /* expr ::= nm DOT nm */
#line 1054 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy146,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy146.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3349 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 155: /* term ::= INTEGER */
#line 1075 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy146.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy146.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy146.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy146.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy146.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy146.pExpr ) yylhsminor.yy146.pExpr->flags |= EP_Leaf;
}
#line 3364 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy146 = yylhsminor.yy146;
        break;
      case 156: /* expr ::= VARIABLE */
#line 1086 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy146, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy146.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy146, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy146.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy146.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy146, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy146.pExpr = NULL;
  }
}
#line 3394 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy146 = yylhsminor.yy146;
        break;
      case 157: /* expr ::= expr COLLATE ID|INDEXED */
#line 1111 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy146.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy146.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy146.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3403 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 158: /* expr ::= CAST LP expr AS typedef RP */
#line 1116 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy146,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy146.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy146.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy146.pExpr->type = yymsp[-1].minor.yy58.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy146.pExpr, yymsp[-3].minor.yy146.pExpr, 0);
}
#line 3417 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 159: /* expr ::= TRIM LP trim_operands RP */
#line 1127 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy146.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy465, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy146, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3425 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-3].minor.yy146 = yylhsminor.yy146;
        break;
      case 160: /* trim_operands ::= trim_from_clause expr */
#line 1135 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy465 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy465, yymsp[0].minor.yy146.pExpr);
}
#line 3433 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-1].minor.yy465 = yylhsminor.yy465;
        break;
      case 161: /* trim_operands ::= expr */
#line 1139 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy465 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy146.pExpr);
}
#line 3441 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy465 = yylhsminor.yy465;
        break;
      case 162: /* trim_from_clause ::= expr FROM */
#line 1151 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy465 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy146.pExpr);
}
#line 3449 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-1].minor.yy465 = yylhsminor.yy465;
        break;
      case 163: /* trim_from_clause ::= trim_specification expr_optional FROM */
#line 1155 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy221]);
  yylhsminor.yy465 = sql_expr_list_append(pParse->db, NULL, p);
  if (yymsp[-1].minor.yy71 != NULL)
    yylhsminor.yy465 = sql_expr_list_append(pParse->db, yylhsminor.yy465, yymsp[-1].minor.yy71);
}
#line 3461 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-2].minor.yy465 = yylhsminor.yy465;
        break;
      case 164: /* expr_optional ::= */
#line 1166 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[1].minor.yy71 = NULL; }
#line 3467 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 165: /* expr_optional ::= expr */
#line 1167 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yylhsminor.yy71 = yymsp[0].minor.yy146.pExpr; }
#line 3472 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy71 = yylhsminor.yy71;
        break;
      case 166: /* trim_specification ::= LEADING */
#line 1171 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy221 = TRIM_LEADING; }
#line 3478 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 167: /* trim_specification ::= TRAILING */
#line 1172 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy221 = TRIM_TRAILING; }
#line 3483 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 168: /* trim_specification ::= BOTH */
#line 1173 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy221 = TRIM_BOTH; }
#line 3488 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 169: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 170: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==170);
#line 1175 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy126 && yymsp[-1].minor.yy126->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy126->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy146.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy126, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy146,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy82==SF_Distinct && yylhsminor.yy146.pExpr ){
    yylhsminor.yy146.pExpr->flags |= EP_Distinct;
  }
}
#line 3507 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-4].minor.yy146 = yylhsminor.yy146;
        break;
      case 171: /* expr ::= ID|INDEXED LP STAR RP */
#line 1210 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy146.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy146,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3516 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-3].minor.yy146 = yylhsminor.yy146;
        break;
      case 172: /* expr ::= LP nexprlist COMMA expr RP */
#line 1245 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy126, yymsp[-1].minor.yy146.pExpr);
  yylhsminor.yy146.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy146.pExpr ){
    yylhsminor.yy146.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy146, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3531 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-4].minor.yy146 = yylhsminor.yy146;
        break;
      case 173: /* expr ::= expr AND expr */
      case 174: /* expr ::= expr OR expr */ yytestcase(yyruleno==174);
      case 175: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==175);
      case 176: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==180);
#line 1256 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy146,&yymsp[0].minor.yy146);}
#line 3544 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 181: /* likeop ::= LIKE_KW|MATCH */
#line 1269 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3549 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 182: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1270 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3554 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 183: /* expr ::= expr likeop expr */
#line 1271 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy146.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy146.pExpr);
  yymsp[-2].minor.yy146.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy146);
  yymsp[-2].minor.yy146.zEnd = yymsp[0].minor.yy146.zEnd;
  if( yymsp[-2].minor.yy146.pExpr ) yymsp[-2].minor.yy146.pExpr->flags |= EP_InfixFunc;
}
#line 3569 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 184: /* expr ::= expr likeop expr ESCAPE expr */
#line 1282 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy146.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy146.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy146.pExpr);
  yymsp[-4].minor.yy146.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy146);
  yymsp[-4].minor.yy146.zEnd = yymsp[0].minor.yy146.zEnd;
  if( yymsp[-4].minor.yy146.pExpr ) yymsp[-4].minor.yy146.pExpr->flags |= EP_InfixFunc;
}
#line 3585 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 185: /* expr ::= expr IS NULL */
#line 1312 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy146,&yymsp[0].minor.yy0);}
#line 3590 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 186: /* expr ::= expr IS NOT NULL */
#line 1313 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy146,&yymsp[0].minor.yy0);}
#line 3595 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 187: /* expr ::= NOT expr */
      case 188: /* expr ::= BITNOT expr */ yytestcase(yyruleno==188);
#line 1335 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy146,pParse,yymsp[-1].major,&yymsp[0].minor.yy146,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3601 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 189: /* expr ::= MINUS expr */
#line 1339 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy146,pParse,TK_UMINUS,&yymsp[0].minor.yy146,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3606 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 190: /* expr ::= PLUS expr */
#line 1341 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy146,pParse,TK_UPLUS,&yymsp[0].minor.yy146,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3611 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 191: /* between_op ::= BETWEEN */
      case 194: /* in_op ::= IN */ yytestcase(yyruleno==194);
#line 1344 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = 0;}
#line 3617 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 193: /* expr ::= expr between_op expr AND expr */
#line 1346 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy146.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy146.pExpr);
  yymsp[-4].minor.yy146.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy146.pExpr, 0);
  if( yymsp[-4].minor.yy146.pExpr ){
    yymsp[-4].minor.yy146.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy82, &yymsp[-4].minor.yy146);
  yymsp[-4].minor.yy146.zEnd = yymsp[0].minor.yy146.zEnd;
}
#line 3633 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 196: /* expr ::= expr in_op LP exprlist RP */
#line 1361 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy126==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy146.pExpr, false);
    int tk = yymsp[-3].minor.yy82 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy146.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy146.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy146.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy126->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy126->a[0].pExpr;
    yymsp[-1].minor.yy126->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy126);
    yymsp[-4].minor.yy146.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy82 ? TK_NE : TK_EQ, yymsp[-4].minor.yy146.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy146.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy146.pExpr, 0);
    if( yymsp[-4].minor.yy146.pExpr ){
      yymsp[-4].minor.yy146.pExpr->x.pList = yymsp[-1].minor.yy126;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy146.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy126);
    }
    exprNot(pParse, yymsp[-3].minor.yy82, &yymsp[-4].minor.yy146);
  }
  yymsp[-4].minor.yy146.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3683 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 197: /* expr ::= LP select RP */
#line 1407 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy146,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy146.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy146.pExpr, yymsp[-1].minor.yy497);
}
#line 3692 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= expr in_op LP select RP */
#line 1412 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy146.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy146.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy146.pExpr, yymsp[-1].minor.yy497);
  exprNot(pParse, yymsp[-3].minor.yy82, &yymsp[-4].minor.yy146);
  yymsp[-4].minor.yy146.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3702 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 199: /* expr ::= expr in_op nm paren_exprlist */
#line 1418 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy126 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy126);
  yymsp[-3].minor.yy146.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy146.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy146.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy82, &yymsp[-3].minor.yy146);
  yymsp[-3].minor.yy146.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3719 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= EXISTS LP select RP */
#line 1431 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy146,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy146.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy497);
}
#line 3729 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1439 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy146,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy146.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy71, 0);
  if( yymsp[-4].minor.yy146.pExpr ){
    yymsp[-4].minor.yy146.pExpr->x.pList = yymsp[-1].minor.yy60 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy126,yymsp[-1].minor.yy60) : yymsp[-2].minor.yy126;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy146.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy126);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy60, false);
  }
}
#line 3744 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 202: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1452 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy126 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy126, yymsp[-2].minor.yy146.pExpr);
  yymsp[-4].minor.yy126 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy126, yymsp[0].minor.yy146.pExpr);
}
#line 3752 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 203: /* case_exprlist ::= WHEN expr THEN expr */
#line 1456 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy126 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy146.pExpr);
  yymsp[-3].minor.yy126 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy126, yymsp[0].minor.yy146.pExpr);
}
#line 3760 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 207: /* nexprlist ::= nexprlist COMMA expr */
#line 1473 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy126 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy126,yymsp[0].minor.yy146.pExpr);}
#line 3765 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 208: /* nexprlist ::= expr */
#line 1475 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy126 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy146.pExpr); /*A-overwrites-Y*/}
#line 3770 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 210: /* paren_exprlist ::= LP exprlist RP */
      case 215: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==215);
#line 1482 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy126 = yymsp[-1].minor.yy126;}
#line 3776 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 211: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1488 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy126, yymsp[-8].minor.yy82,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy82);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3791 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 212: /* uniqueflag ::= UNIQUE */
#line 1501 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = SQL_INDEX_TYPE_UNIQUE;}
#line 3796 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 213: /* uniqueflag ::= */
#line 1502 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy82 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3801 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 216: /* eidlist ::= eidlist COMMA nm */
#line 1537 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy126 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy126, &yymsp[0].minor.yy0);
}
#line 3808 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 217: /* eidlist ::= nm */
#line 1540 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[0].minor.yy126 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3815 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 218: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1547 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy27, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy82);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3824 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 219: /* cmd ::= SET SESSION nm EQ term */
#line 1555 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy146.pExpr);
}
#line 3831 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 220: /* cmd ::= PRAGMA nm */
#line 1561 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3838 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 221: /* cmd ::= PRAGMA nm LP nm RP */
#line 1564 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3845 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1567 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3852 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 223: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1572 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy93, &all);
}
#line 3863 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 224: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1582 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy27, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy82, yymsp[-4].minor.yy466.a, yymsp[-4].minor.yy466.b, yymsp[0].minor.yy60,
                          yymsp[-7].minor.yy82);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3873 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 225: /* trigger_time ::= BEFORE */
#line 1590 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy82 = TK_BEFORE; }
#line 3878 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 226: /* trigger_time ::= AFTER */
#line 1591 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy82 = TK_AFTER;  }
#line 3883 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 227: /* trigger_time ::= INSTEAD OF */
#line 1592 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = TK_INSTEAD;}
#line 3888 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 228: /* trigger_time ::= */
#line 1593 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[1].minor.yy82 = TK_BEFORE; }
#line 3893 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 229: /* trigger_event ::= DELETE|INSERT */
      case 230: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==230);
#line 1597 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy466.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy466.b = 0;}
#line 3899 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 231: /* trigger_event ::= UPDATE OF idlist */
#line 1599 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[-2].minor.yy466.a = TK_UPDATE; yymsp[-2].minor.yy466.b = yymsp[0].minor.yy200;}
#line 3904 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 232: /* foreach_clause ::= */
#line 1601 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3914 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 233: /* when_clause ::= */
#line 1611 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[1].minor.yy60 = 0; }
#line 3919 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 234: /* when_clause ::= WHEN expr */
#line 1612 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy60 = yymsp[0].minor.yy146.pExpr; }
#line 3924 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 235: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1616 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy93!=0 );
  yymsp[-2].minor.yy93->pLast->pNext = yymsp[-1].minor.yy93;
  yymsp[-2].minor.yy93->pLast = yymsp[-1].minor.yy93;
}
#line 3933 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 236: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1621 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy93!=0 );
  yymsp[-1].minor.yy93->pLast = yymsp[-1].minor.yy93;
}
#line 3941 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 237: /* trnm ::= nm DOT nm */
#line 1632 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3952 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 238: /* tridxby ::= INDEXED BY nm */
#line 1645 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3962 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 239: /* tridxby ::= NOT INDEXED */
#line 1651 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3972 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 240: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1664 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy93 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy126, yymsp[0].minor.yy60, yymsp[-5].minor.yy82);
     if (yymsp[-6].minor.yy93 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3983 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 241: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1673 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  /*yylhsminor.yy93-overwrites-yymsp[-4].minor.yy82. */
  yylhsminor.yy93 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy200, yymsp[0].minor.yy497, yymsp[-4].minor.yy82);
  if (yylhsminor.yy93 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3995 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-4].minor.yy93 = yylhsminor.yy93;
        break;
      case 242: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1683 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy93 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy60);
  if (yymsp[-4].minor.yy93 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4007 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 243: /* trigger_cmd ::= select */
#line 1692 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  /* yylhsminor.yy93-overwrites-yymsp[0].minor.yy497. */
  yylhsminor.yy93 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy497);
  if (yylhsminor.yy93 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4019 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy93 = yylhsminor.yy93;
        break;
      case 244: /* expr ::= RAISE LP IGNORE RP */
#line 1702 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy146,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy146.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy146.pExpr ){
    yymsp[-3].minor.yy146.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4031 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 245: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1709 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy146,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy146.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy146.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy146.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy82;
}
#line 4044 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 246: /* raisetype ::= ROLLBACK */
#line 1720 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4049 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 247: /* raisetype ::= ABORT */
#line 1721 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = ON_CONFLICT_ACTION_ABORT;}
#line 4054 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 248: /* raisetype ::= FAIL */
#line 1722 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[0].minor.yy82 = ON_CONFLICT_ACTION_FAIL;}
#line 4059 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 249: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1726 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy27, &t, yymsp[-1].minor.yy82);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4069 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 250: /* alter_table_start ::= ALTER TABLE fullname */
#line 1743 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-2].minor.yy512 = yymsp[0].minor.yy27; }
#line 4074 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 251: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1746 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
   yylhsminor.yy402.table_name = yymsp[-3].minor.yy512;
   yylhsminor.yy402.name = yymsp[0].minor.yy0;
   pParse->initiateTTrans = true;
 }
#line 4083 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-3].minor.yy402 = yylhsminor.yy402;
        break;
      case 252: /* alter_add_column ::= alter_table_start ADD column_name */
#line 1753 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yylhsminor.yy402.table_name = yymsp[-2].minor.yy512;
  yylhsminor.yy402.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4093 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[-2].minor.yy402 = yylhsminor.yy402;
        break;
      case 253: /* column_name ::= COLUMN nm */
#line 1759 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4099 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 254: /* column_name ::= nm */
#line 1760 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 4104 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 255: /* alter_column_def ::= alter_add_column typedef */
#line 1764 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, yymsp[-1].minor.yy402.table_name, &yymsp[-1].minor.yy402.name, &yymsp[0].minor.yy58);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  sql_create_column_start(pParse);
}
#line 4115 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 256: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1772 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy402.table_name, &yymsp[-11].minor.yy402.name, yymsp[-7].minor.yy126, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy126,
                     yymsp[-2].minor.yy82, yymsp[-1].minor.yy82, yymsp[0].minor.yy82);
  sql_create_foreign_key(pParse);
}
#line 4124 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 257: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1778 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy402.table_name, &yymsp[-4].minor.yy402.name, &yymsp[-1].minor.yy146);
    sql_create_check_contraint(pParse);
}
#line 4132 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 258: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1783 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy402.table_name, &yymsp[-4].minor.yy402.name, yymsp[-1].minor.yy126, yymsp[-3].minor.yy82,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4141 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 259: /* unique_spec ::= UNIQUE */
#line 1790 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy82 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4146 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 260: /* unique_spec ::= PRIMARY KEY */
#line 1791 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy82 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4151 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 261: /* cmd ::= alter_table_start RENAME TO nm */
#line 1793 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy512, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4160 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 262: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1799 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy27, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4169 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 263: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1805 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy512,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy28);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4178 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 264: /* with ::= */
#line 1817 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{yymsp[1].minor.yy79 = 0;}
#line 4183 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 265: /* with ::= WITH wqlist */
#line 1818 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-1].minor.yy79 = yymsp[0].minor.yy79; }
#line 4188 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 266: /* with ::= WITH RECURSIVE wqlist */
#line 1819 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[-2].minor.yy79 = yymsp[0].minor.yy79; }
#line 4193 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 267: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1821 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy79 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy126, yymsp[-1].minor.yy497); /*A-overwrites-X*/
}
#line 4200 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 268: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1824 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy79 = sqlWithAdd(pParse, yymsp[-7].minor.yy79, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy126, yymsp[-1].minor.yy497);
}
#line 4207 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 269: /* typedef ::= TEXT */
      case 270: /* typedef ::= STRING_KW */ yytestcase(yyruleno==270);
#line 1830 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_STRING; }
#line 4213 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 271: /* typedef ::= SCALAR */
#line 1832 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_SCALAR; }
#line 4218 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 272: /* typedef ::= BOOL */
      case 273: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==273);
#line 1834 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_BOOLEAN; }
#line 4224 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 274: /* typedef ::= VARBINARY */
#line 1836 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_VARBINARY; }
#line 4229 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 275: /* typedef ::= UUID */
#line 1837 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_UUID; }
#line 4234 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 276: /* char_len ::= LP INTEGER RP */
#line 1849 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy82;
  (void) yymsp[-1].minor.yy0;
}
#line 4242 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 277: /* typedef ::= VARCHAR char_len */
#line 1855 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy58.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy82;
}
#line 4250 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 278: /* number_typedef ::= NUMBER */
#line 1862 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_NUMBER; }
#line 4255 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 279: /* number_typedef ::= DOUBLE */
#line 1863 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_DOUBLE; }
#line 4260 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 280: /* number_typedef ::= INT|INTEGER_KW */
#line 1864 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_INTEGER; }
#line 4265 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 281: /* number_typedef ::= UNSIGNED */
#line 1865 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_UNSIGNED; }
#line 4270 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      case 282: /* number_typedef ::= DECIMAL */
#line 1866 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"
{ yymsp[0].minor.yy58.type = FIELD_TYPE_DECIMAL; }
#line 4275 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
        break;
      default:
      /* (283) input ::= ecmd */ yytestcase(yyruleno==283);
      /* (284) explain ::= */ yytestcase(yyruleno==284);
      /* (285) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=285);
      /* (286) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==286);
      /* (287) savepoint_opt ::= */ yytestcase(yyruleno==287);
      /* (288) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==288);
      /* (289) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==289);
      /* (290) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==290);
      /* (291) with_opts ::= */ yytestcase(yyruleno==291);
      /* (292) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==292);
      /* (293) columnlist ::= columnlist COMMA column_def create_column_end */ yytestcase(yyruleno==293);
      /* (294) columnlist ::= column_def create_column_end */ yytestcase(yyruleno==294);
      /* (295) column_def ::= column_name_and_type carglist */ yytestcase(yyruleno==295);
      /* (296) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=296);
      /* (297) carglist ::= carglist ccons */ yytestcase(yyruleno==297);
      /* (298) carglist ::= */ yytestcase(yyruleno==298);
      /* (299) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=299);
      /* (300) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=300);
      /* (301) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=302);
      /* (303) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=303);
      /* (304) oneselect ::= values */ yytestcase(yyruleno==304);
      /* (305) sclp ::= selcollist COMMA */ yytestcase(yyruleno==305);
      /* (306) as ::= ID|STRING */ yytestcase(yyruleno==306);
      /* (307) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==307);
      /* (308) join_nm ::= JOIN_KW */ yytestcase(yyruleno==308);
      /* (309) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=309);
      /* (310) type_func ::= CHAR */ yytestcase(yyruleno==310);
      /* (311) exprlist ::= nexprlist */ yytestcase(yyruleno==311);
      /* (312) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==312);
      /* (313) trnm ::= nm */ yytestcase(yyruleno==313);
      /* (314) tridxby ::= */ yytestcase(yyruleno==314);
      /* (315) cmd ::= alter_column_def carglist create_column_end */ yytestcase(yyruleno==315);
      /* (316) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=316);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4380 "/build/usr/src/debug/tarantool-2.9.0.342/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
